@@ -14,7 +14,8 @@ def baomihua_download_by_id(id, title=None, output_dir='.', merge=True, info_onl
     assert type
     vid = r1(r'&stream_name=([^&]*)', html)
     assert vid
-    url = "http://%s/pomoho_video/%s.%s" % (host, vid, type)
+    dir_str = r1(r'&dir=([^&]*)', html).strip()
+    url = "http://%s/%s/%s.%s" % (host, dir_str, vid, type)
     _, ext, size = url_info(url)
     print_info(site_info, title, type, size)
     if not info_only:
